// test_demo.c

#include <stdio.h>
#include <stdlib.h>
#include <assert.h>
#include <time.h>
#include "demo.c"


// Struct for time
struct timespec start_time;
struct timespec end_time;

// Instrumentation functions
void __attribute__((no_instrument_function)) __cyg_profile_func_enter(void *, void *func_addr) {
	clock_gettime(CLOCK_MONOTONIC, &start_time); // Az időzítő elindítása a függvénybelépési ponton
    printf("Entered function at address %p\n", func_addr);
}

void __attribute__((no_instrument_function)) __cyg_profile_func_exit(void *, void *func_addr) {
	 clock_gettime(CLOCK_MONOTONIC, &end_time); // Az időzítő leállítása a függvénykilépési ponton
    double elapsed_time = (end_time.tv_sec - start_time.tv_sec) + (end_time.tv_nsec - start_time.tv_nsec) / 1e9; // Az eltelt idő kiszámítása másodpercben
    printf("Exited function at address %p ran for %.6f seconds \n", func_addr, elapsed_time); 
}


// Test cases
void test_add() {
	printf("test_add\n");
    int result = add(2, 3);
    if (result != 5) {
        printf("Test add failed: Expected 5, got %d\n", result);
    } else {
        printf("Test add passed!\n");
    }
}

void test_subtract() {
	printf("test_subtract\n");
    int result = subtract(5, 2);
    if (result != 3) {
        printf("Test subtract failed: Expected 3, got %d\n", result);
    } else {
        printf("Test subtract passed!\n");
    }
}


int main() {
	printf("main\n");
	
    // Running test cases
    test_add();
    test_subtract();
    return 0;
}